// Auto generated 2022-03-29 22:40:59 +0300
extern crate phf_codegen;

use std::env;
use std::fs::File;
use std::io::{BufWriter, Write};
use std::path::Path;

fn main() {
    let path = Path::new(&env::var("OUT_DIR").unwrap()).join("codegen.rs");
    let mut file = BufWriter::new(File::create(&path).unwrap());

    writeln!(
        &mut file,
        "/// Top level domain static map, list is obtained from iana.org."
    )
    .unwrap();

    writeln!(
        &mut file,
        "pub static TLD: phf::Set<&'static str> = {};",
        phf_codegen::Set::new()
            .entry("aaa")
            .entry("aarp")
            .entry("abarth")
            .entry("abb")
            .entry("abbott")
            .entry("abbvie")
            .entry("abc")
            .entry("able")
            .entry("abogado")
            .entry("abudhabi")
            .entry("ac")
            .entry("academy")
            .entry("accenture")
            .entry("accountant")
            .entry("accountants")
            .entry("aco")
            .entry("actor")
            .entry("ad")
            .entry("adac")
            .entry("ads")
            .entry("adult")
            .entry("ae")
            .entry("aeg")
            .entry("aero")
            .entry("aetna")
            .entry("af")
            .entry("afl")
            .entry("africa")
            .entry("ag")
            .entry("agakhan")
            .entry("agency")
            .entry("ai")
            .entry("aig")
            .entry("airbus")
            .entry("airforce")
            .entry("airtel")
            .entry("akdn")
            .entry("al")
            .entry("alfaromeo")
            .entry("alibaba")
            .entry("alipay")
            .entry("allfinanz")
            .entry("allstate")
            .entry("ally")
            .entry("alsace")
            .entry("alstom")
            .entry("am")
            .entry("amazon")
            .entry("americanexpress")
            .entry("americanfamily")
            .entry("amex")
            .entry("amfam")
            .entry("amica")
            .entry("amsterdam")
            .entry("analytics")
            .entry("android")
            .entry("anquan")
            .entry("anz")
            .entry("ao")
            .entry("aol")
            .entry("apartments")
            .entry("app")
            .entry("apple")
            .entry("aq")
            .entry("aquarelle")
            .entry("ar")
            .entry("arab")
            .entry("aramco")
            .entry("archi")
            .entry("army")
            .entry("arpa")
            .entry("art")
            .entry("arte")
            .entry("as")
            .entry("asda")
            .entry("asia")
            .entry("associates")
            .entry("at")
            .entry("athleta")
            .entry("attorney")
            .entry("au")
            .entry("auction")
            .entry("audi")
            .entry("audible")
            .entry("audio")
            .entry("auspost")
            .entry("author")
            .entry("auto")
            .entry("autos")
            .entry("avianca")
            .entry("aw")
            .entry("aws")
            .entry("ax")
            .entry("axa")
            .entry("az")
            .entry("azure")
            .entry("ba")
            .entry("baby")
            .entry("baidu")
            .entry("banamex")
            .entry("bananarepublic")
            .entry("band")
            .entry("bank")
            .entry("bar")
            .entry("barcelona")
            .entry("barclaycard")
            .entry("barclays")
            .entry("barefoot")
            .entry("bargains")
            .entry("baseball")
            .entry("basketball")
            .entry("bauhaus")
            .entry("bayern")
            .entry("bb")
            .entry("bbc")
            .entry("bbt")
            .entry("bbva")
            .entry("bcg")
            .entry("bcn")
            .entry("bd")
            .entry("be")
            .entry("beats")
            .entry("beauty")
            .entry("beer")
            .entry("bentley")
            .entry("berlin")
            .entry("best")
            .entry("bestbuy")
            .entry("bet")
            .entry("bf")
            .entry("bg")
            .entry("bh")
            .entry("bharti")
            .entry("bi")
            .entry("bible")
            .entry("bid")
            .entry("bike")
            .entry("bing")
            .entry("bingo")
            .entry("bio")
            .entry("biz")
            .entry("bj")
            .entry("black")
            .entry("blackfriday")
            .entry("blockbuster")
            .entry("blog")
            .entry("bloomberg")
            .entry("blue")
            .entry("bm")
            .entry("bms")
            .entry("bmw")
            .entry("bn")
            .entry("bnpparibas")
            .entry("bo")
            .entry("boats")
            .entry("boehringer")
            .entry("bofa")
            .entry("bom")
            .entry("bond")
            .entry("boo")
            .entry("book")
            .entry("booking")
            .entry("bosch")
            .entry("bostik")
            .entry("boston")
            .entry("bot")
            .entry("boutique")
            .entry("box")
            .entry("br")
            .entry("bradesco")
            .entry("bridgestone")
            .entry("broadway")
            .entry("broker")
            .entry("brother")
            .entry("brussels")
            .entry("bs")
            .entry("bt")
            .entry("bugatti")
            .entry("build")
            .entry("builders")
            .entry("business")
            .entry("buy")
            .entry("buzz")
            .entry("bv")
            .entry("bw")
            .entry("by")
            .entry("bz")
            .entry("bzh")
            .entry("ca")
            .entry("cab")
            .entry("cafe")
            .entry("cal")
            .entry("call")
            .entry("calvinklein")
            .entry("cam")
            .entry("camera")
            .entry("camp")
            .entry("cancerresearch")
            .entry("canon")
            .entry("capetown")
            .entry("capital")
            .entry("capitalone")
            .entry("car")
            .entry("caravan")
            .entry("cards")
            .entry("care")
            .entry("career")
            .entry("careers")
            .entry("cars")
            .entry("casa")
            .entry("case")
            .entry("cash")
            .entry("casino")
            .entry("cat")
            .entry("catering")
            .entry("catholic")
            .entry("cba")
            .entry("cbn")
            .entry("cbre")
            .entry("cbs")
            .entry("cc")
            .entry("cd")
            .entry("center")
            .entry("ceo")
            .entry("cern")
            .entry("cf")
            .entry("cfa")
            .entry("cfd")
            .entry("cg")
            .entry("ch")
            .entry("chanel")
            .entry("channel")
            .entry("charity")
            .entry("chase")
            .entry("chat")
            .entry("cheap")
            .entry("chintai")
            .entry("christmas")
            .entry("chrome")
            .entry("church")
            .entry("ci")
            .entry("cipriani")
            .entry("circle")
            .entry("cisco")
            .entry("citadel")
            .entry("citi")
            .entry("citic")
            .entry("city")
            .entry("cityeats")
            .entry("ck")
            .entry("cl")
            .entry("claims")
            .entry("cleaning")
            .entry("click")
            .entry("clinic")
            .entry("clinique")
            .entry("clothing")
            .entry("cloud")
            .entry("club")
            .entry("clubmed")
            .entry("cm")
            .entry("cn")
            .entry("co")
            .entry("coach")
            .entry("codes")
            .entry("coffee")
            .entry("college")
            .entry("cologne")
            .entry("com")
            .entry("comcast")
            .entry("commbank")
            .entry("community")
            .entry("company")
            .entry("compare")
            .entry("computer")
            .entry("comsec")
            .entry("condos")
            .entry("construction")
            .entry("consulting")
            .entry("contact")
            .entry("contractors")
            .entry("cooking")
            .entry("cookingchannel")
            .entry("cool")
            .entry("coop")
            .entry("corsica")
            .entry("country")
            .entry("coupon")
            .entry("coupons")
            .entry("courses")
            .entry("cpa")
            .entry("cr")
            .entry("credit")
            .entry("creditcard")
            .entry("creditunion")
            .entry("cricket")
            .entry("crown")
            .entry("crs")
            .entry("cruise")
            .entry("cruises")
            .entry("cu")
            .entry("cuisinella")
            .entry("cv")
            .entry("cw")
            .entry("cx")
            .entry("cy")
            .entry("cymru")
            .entry("cyou")
            .entry("cz")
            .entry("dabur")
            .entry("dad")
            .entry("dance")
            .entry("data")
            .entry("date")
            .entry("dating")
            .entry("datsun")
            .entry("day")
            .entry("dclk")
            .entry("dds")
            .entry("de")
            .entry("deal")
            .entry("dealer")
            .entry("deals")
            .entry("degree")
            .entry("delivery")
            .entry("dell")
            .entry("deloitte")
            .entry("delta")
            .entry("democrat")
            .entry("dental")
            .entry("dentist")
            .entry("desi")
            .entry("design")
            .entry("dev")
            .entry("dhl")
            .entry("diamonds")
            .entry("diet")
            .entry("digital")
            .entry("direct")
            .entry("directory")
            .entry("discount")
            .entry("discover")
            .entry("dish")
            .entry("diy")
            .entry("dj")
            .entry("dk")
            .entry("dm")
            .entry("dnp")
            .entry("do")
            .entry("docs")
            .entry("doctor")
            .entry("dog")
            .entry("domains")
            .entry("dot")
            .entry("download")
            .entry("drive")
            .entry("dtv")
            .entry("dubai")
            .entry("dunlop")
            .entry("dupont")
            .entry("durban")
            .entry("dvag")
            .entry("dvr")
            .entry("dz")
            .entry("earth")
            .entry("eat")
            .entry("ec")
            .entry("eco")
            .entry("edeka")
            .entry("edu")
            .entry("education")
            .entry("ee")
            .entry("eg")
            .entry("email")
            .entry("emerck")
            .entry("energy")
            .entry("engineer")
            .entry("engineering")
            .entry("enterprises")
            .entry("epson")
            .entry("equipment")
            .entry("er")
            .entry("ericsson")
            .entry("erni")
            .entry("es")
            .entry("esq")
            .entry("estate")
            .entry("et")
            .entry("etisalat")
            .entry("eu")
            .entry("eurovision")
            .entry("eus")
            .entry("events")
            .entry("exchange")
            .entry("expert")
            .entry("exposed")
            .entry("express")
            .entry("extraspace")
            .entry("fage")
            .entry("fail")
            .entry("fairwinds")
            .entry("faith")
            .entry("family")
            .entry("fan")
            .entry("fans")
            .entry("farm")
            .entry("farmers")
            .entry("fashion")
            .entry("fast")
            .entry("fedex")
            .entry("feedback")
            .entry("ferrari")
            .entry("ferrero")
            .entry("fi")
            .entry("fiat")
            .entry("fidelity")
            .entry("fido")
            .entry("film")
            .entry("final")
            .entry("finance")
            .entry("financial")
            .entry("fire")
            .entry("firestone")
            .entry("firmdale")
            .entry("fish")
            .entry("fishing")
            .entry("fit")
            .entry("fitness")
            .entry("fj")
            .entry("fk")
            .entry("flickr")
            .entry("flights")
            .entry("flir")
            .entry("florist")
            .entry("flowers")
            .entry("fly")
            .entry("fm")
            .entry("fo")
            .entry("foo")
            .entry("food")
            .entry("foodnetwork")
            .entry("football")
            .entry("ford")
            .entry("forex")
            .entry("forsale")
            .entry("forum")
            .entry("foundation")
            .entry("fox")
            .entry("fr")
            .entry("free")
            .entry("fresenius")
            .entry("frl")
            .entry("frogans")
            .entry("frontdoor")
            .entry("frontier")
            .entry("ftr")
            .entry("fujitsu")
            .entry("fun")
            .entry("fund")
            .entry("furniture")
            .entry("futbol")
            .entry("fyi")
            .entry("ga")
            .entry("gal")
            .entry("gallery")
            .entry("gallo")
            .entry("gallup")
            .entry("game")
            .entry("games")
            .entry("gap")
            .entry("garden")
            .entry("gay")
            .entry("gb")
            .entry("gbiz")
            .entry("gd")
            .entry("gdn")
            .entry("ge")
            .entry("gea")
            .entry("gent")
            .entry("genting")
            .entry("george")
            .entry("gf")
            .entry("gg")
            .entry("ggee")
            .entry("gh")
            .entry("gi")
            .entry("gift")
            .entry("gifts")
            .entry("gives")
            .entry("giving")
            .entry("gl")
            .entry("glass")
            .entry("gle")
            .entry("global")
            .entry("globo")
            .entry("gm")
            .entry("gmail")
            .entry("gmbh")
            .entry("gmo")
            .entry("gmx")
            .entry("gn")
            .entry("godaddy")
            .entry("gold")
            .entry("goldpoint")
            .entry("golf")
            .entry("goo")
            .entry("goodyear")
            .entry("goog")
            .entry("google")
            .entry("gop")
            .entry("got")
            .entry("gov")
            .entry("gp")
            .entry("gq")
            .entry("gr")
            .entry("grainger")
            .entry("graphics")
            .entry("gratis")
            .entry("green")
            .entry("gripe")
            .entry("grocery")
            .entry("group")
            .entry("gs")
            .entry("gt")
            .entry("gu")
            .entry("guardian")
            .entry("gucci")
            .entry("guge")
            .entry("guide")
            .entry("guitars")
            .entry("guru")
            .entry("gw")
            .entry("gy")
            .entry("hair")
            .entry("hamburg")
            .entry("hangout")
            .entry("haus")
            .entry("hbo")
            .entry("hdfc")
            .entry("hdfcbank")
            .entry("health")
            .entry("healthcare")
            .entry("help")
            .entry("helsinki")
            .entry("here")
            .entry("hermes")
            .entry("hgtv")
            .entry("hiphop")
            .entry("hisamitsu")
            .entry("hitachi")
            .entry("hiv")
            .entry("hk")
            .entry("hkt")
            .entry("hm")
            .entry("hn")
            .entry("hockey")
            .entry("holdings")
            .entry("holiday")
            .entry("homedepot")
            .entry("homegoods")
            .entry("homes")
            .entry("homesense")
            .entry("honda")
            .entry("horse")
            .entry("hospital")
            .entry("host")
            .entry("hosting")
            .entry("hot")
            .entry("hoteles")
            .entry("hotels")
            .entry("hotmail")
            .entry("house")
            .entry("how")
            .entry("hr")
            .entry("hsbc")
            .entry("ht")
            .entry("hu")
            .entry("hughes")
            .entry("hyatt")
            .entry("hyundai")
            .entry("ibm")
            .entry("icbc")
            .entry("ice")
            .entry("icu")
            .entry("id")
            .entry("ie")
            .entry("ieee")
            .entry("ifm")
            .entry("ikano")
            .entry("il")
            .entry("im")
            .entry("imamat")
            .entry("imdb")
            .entry("immo")
            .entry("immobilien")
            .entry("in")
            .entry("inc")
            .entry("industries")
            .entry("infiniti")
            .entry("info")
            .entry("ing")
            .entry("ink")
            .entry("institute")
            .entry("insurance")
            .entry("insure")
            .entry("int")
            .entry("international")
            .entry("intuit")
            .entry("investments")
            .entry("io")
            .entry("ipiranga")
            .entry("iq")
            .entry("ir")
            .entry("irish")
            .entry("is")
            .entry("ismaili")
            .entry("ist")
            .entry("istanbul")
            .entry("it")
            .entry("itau")
            .entry("itv")
            .entry("jaguar")
            .entry("java")
            .entry("jcb")
            .entry("je")
            .entry("jeep")
            .entry("jetzt")
            .entry("jewelry")
            .entry("jio")
            .entry("jll")
            .entry("jm")
            .entry("jmp")
            .entry("jnj")
            .entry("jo")
            .entry("jobs")
            .entry("joburg")
            .entry("jot")
            .entry("joy")
            .entry("jp")
            .entry("jpmorgan")
            .entry("jprs")
            .entry("juegos")
            .entry("juniper")
            .entry("kaufen")
            .entry("kddi")
            .entry("ke")
            .entry("kerryhotels")
            .entry("kerrylogistics")
            .entry("kerryproperties")
            .entry("kfh")
            .entry("kg")
            .entry("kh")
            .entry("ki")
            .entry("kia")
            .entry("kim")
            .entry("kinder")
            .entry("kindle")
            .entry("kitchen")
            .entry("kiwi")
            .entry("km")
            .entry("kn")
            .entry("koeln")
            .entry("komatsu")
            .entry("kosher")
            .entry("kp")
            .entry("kpmg")
            .entry("kpn")
            .entry("kr")
            .entry("krd")
            .entry("kred")
            .entry("kuokgroup")
            .entry("kw")
            .entry("ky")
            .entry("kyoto")
            .entry("kz")
            .entry("la")
            .entry("lacaixa")
            .entry("lamborghini")
            .entry("lamer")
            .entry("lancaster")
            .entry("lancia")
            .entry("land")
            .entry("landrover")
            .entry("lanxess")
            .entry("lasalle")
            .entry("lat")
            .entry("latino")
            .entry("latrobe")
            .entry("law")
            .entry("lawyer")
            .entry("lb")
            .entry("lc")
            .entry("lds")
            .entry("lease")
            .entry("leclerc")
            .entry("lefrak")
            .entry("legal")
            .entry("lego")
            .entry("lexus")
            .entry("lgbt")
            .entry("li")
            .entry("lidl")
            .entry("life")
            .entry("lifeinsurance")
            .entry("lifestyle")
            .entry("lighting")
            .entry("like")
            .entry("lilly")
            .entry("limited")
            .entry("limo")
            .entry("lincoln")
            .entry("linde")
            .entry("link")
            .entry("lipsy")
            .entry("live")
            .entry("living")
            .entry("lk")
            .entry("llc")
            .entry("llp")
            .entry("loan")
            .entry("loans")
            .entry("locker")
            .entry("locus")
            .entry("loft")
            .entry("lol")
            .entry("london")
            .entry("lotte")
            .entry("lotto")
            .entry("love")
            .entry("lpl")
            .entry("lplfinancial")
            .entry("lr")
            .entry("ls")
            .entry("lt")
            .entry("ltd")
            .entry("ltda")
            .entry("lu")
            .entry("lundbeck")
            .entry("luxe")
            .entry("luxury")
            .entry("lv")
            .entry("ly")
            .entry("ma")
            .entry("macys")
            .entry("madrid")
            .entry("maif")
            .entry("maison")
            .entry("makeup")
            .entry("man")
            .entry("management")
            .entry("mango")
            .entry("map")
            .entry("market")
            .entry("marketing")
            .entry("markets")
            .entry("marriott")
            .entry("marshalls")
            .entry("maserati")
            .entry("mattel")
            .entry("mba")
            .entry("mc")
            .entry("mckinsey")
            .entry("md")
            .entry("me")
            .entry("med")
            .entry("media")
            .entry("meet")
            .entry("melbourne")
            .entry("meme")
            .entry("memorial")
            .entry("men")
            .entry("menu")
            .entry("merckmsd")
            .entry("mg")
            .entry("mh")
            .entry("miami")
            .entry("microsoft")
            .entry("mil")
            .entry("mini")
            .entry("mint")
            .entry("mit")
            .entry("mitsubishi")
            .entry("mk")
            .entry("ml")
            .entry("mlb")
            .entry("mls")
            .entry("mm")
            .entry("mma")
            .entry("mn")
            .entry("mo")
            .entry("mobi")
            .entry("mobile")
            .entry("moda")
            .entry("moe")
            .entry("moi")
            .entry("mom")
            .entry("monash")
            .entry("money")
            .entry("monster")
            .entry("mormon")
            .entry("mortgage")
            .entry("moscow")
            .entry("moto")
            .entry("motorcycles")
            .entry("mov")
            .entry("movie")
            .entry("mp")
            .entry("mq")
            .entry("mr")
            .entry("ms")
            .entry("msd")
            .entry("mt")
            .entry("mtn")
            .entry("mtr")
            .entry("mu")
            .entry("museum")
            .entry("music")
            .entry("mutual")
            .entry("mv")
            .entry("mw")
            .entry("mx")
            .entry("my")
            .entry("mz")
            .entry("na")
            .entry("nab")
            .entry("nagoya")
            .entry("name")
            .entry("natura")
            .entry("navy")
            .entry("nba")
            .entry("nc")
            .entry("ne")
            .entry("nec")
            .entry("net")
            .entry("netbank")
            .entry("netflix")
            .entry("network")
            .entry("neustar")
            .entry("new")
            .entry("news")
            .entry("next")
            .entry("nextdirect")
            .entry("nexus")
            .entry("nf")
            .entry("nfl")
            .entry("ng")
            .entry("ngo")
            .entry("nhk")
            .entry("ni")
            .entry("nico")
            .entry("nike")
            .entry("nikon")
            .entry("ninja")
            .entry("nissan")
            .entry("nissay")
            .entry("nl")
            .entry("no")
            .entry("nokia")
            .entry("northwesternmutual")
            .entry("norton")
            .entry("now")
            .entry("nowruz")
            .entry("nowtv")
            .entry("np")
            .entry("nr")
            .entry("nra")
            .entry("nrw")
            .entry("ntt")
            .entry("nu")
            .entry("nyc")
            .entry("nz")
            .entry("obi")
            .entry("observer")
            .entry("office")
            .entry("okinawa")
            .entry("olayan")
            .entry("olayangroup")
            .entry("oldnavy")
            .entry("ollo")
            .entry("om")
            .entry("omega")
            .entry("one")
            .entry("ong")
            .entry("onl")
            .entry("online")
            .entry("ooo")
            .entry("open")
            .entry("oracle")
            .entry("orange")
            .entry("org")
            .entry("organic")
            .entry("origins")
            .entry("osaka")
            .entry("otsuka")
            .entry("ott")
            .entry("ovh")
            .entry("pa")
            .entry("page")
            .entry("panasonic")
            .entry("paris")
            .entry("pars")
            .entry("partners")
            .entry("parts")
            .entry("party")
            .entry("passagens")
            .entry("pay")
            .entry("pccw")
            .entry("pe")
            .entry("pet")
            .entry("pf")
            .entry("pfizer")
            .entry("pg")
            .entry("ph")
            .entry("pharmacy")
            .entry("phd")
            .entry("philips")
            .entry("phone")
            .entry("photo")
            .entry("photography")
            .entry("photos")
            .entry("physio")
            .entry("pics")
            .entry("pictet")
            .entry("pictures")
            .entry("pid")
            .entry("pin")
            .entry("ping")
            .entry("pink")
            .entry("pioneer")
            .entry("pizza")
            .entry("pk")
            .entry("pl")
            .entry("place")
            .entry("play")
            .entry("playstation")
            .entry("plumbing")
            .entry("plus")
            .entry("pm")
            .entry("pn")
            .entry("pnc")
            .entry("pohl")
            .entry("poker")
            .entry("politie")
            .entry("porn")
            .entry("post")
            .entry("pr")
            .entry("pramerica")
            .entry("praxi")
            .entry("press")
            .entry("prime")
            .entry("pro")
            .entry("prod")
            .entry("productions")
            .entry("prof")
            .entry("progressive")
            .entry("promo")
            .entry("properties")
            .entry("property")
            .entry("protection")
            .entry("pru")
            .entry("prudential")
            .entry("ps")
            .entry("pt")
            .entry("pub")
            .entry("pw")
            .entry("pwc")
            .entry("py")
            .entry("qa")
            .entry("qpon")
            .entry("quebec")
            .entry("quest")
            .entry("racing")
            .entry("radio")
            .entry("re")
            .entry("read")
            .entry("realestate")
            .entry("realtor")
            .entry("realty")
            .entry("recipes")
            .entry("red")
            .entry("redstone")
            .entry("redumbrella")
            .entry("rehab")
            .entry("reise")
            .entry("reisen")
            .entry("reit")
            .entry("reliance")
            .entry("ren")
            .entry("rent")
            .entry("rentals")
            .entry("repair")
            .entry("report")
            .entry("republican")
            .entry("rest")
            .entry("restaurant")
            .entry("review")
            .entry("reviews")
            .entry("rexroth")
            .entry("rich")
            .entry("richardli")
            .entry("ricoh")
            .entry("ril")
            .entry("rio")
            .entry("rip")
            .entry("ro")
            .entry("rocher")
            .entry("rocks")
            .entry("rodeo")
            .entry("rogers")
            .entry("room")
            .entry("rs")
            .entry("rsvp")
            .entry("ru")
            .entry("rugby")
            .entry("ruhr")
            .entry("run")
            .entry("rw")
            .entry("rwe")
            .entry("ryukyu")
            .entry("sa")
            .entry("saarland")
            .entry("safe")
            .entry("safety")
            .entry("sakura")
            .entry("sale")
            .entry("salon")
            .entry("samsclub")
            .entry("samsung")
            .entry("sandvik")
            .entry("sandvikcoromant")
            .entry("sanofi")
            .entry("sap")
            .entry("sarl")
            .entry("sas")
            .entry("save")
            .entry("saxo")
            .entry("sb")
            .entry("sbi")
            .entry("sbs")
            .entry("sc")
            .entry("sca")
            .entry("scb")
            .entry("schaeffler")
            .entry("schmidt")
            .entry("scholarships")
            .entry("school")
            .entry("schule")
            .entry("schwarz")
            .entry("science")
            .entry("scot")
            .entry("sd")
            .entry("se")
            .entry("search")
            .entry("seat")
            .entry("secure")
            .entry("security")
            .entry("seek")
            .entry("select")
            .entry("sener")
            .entry("services")
            .entry("ses")
            .entry("seven")
            .entry("sew")
            .entry("sex")
            .entry("sexy")
            .entry("sfr")
            .entry("sg")
            .entry("sh")
            .entry("shangrila")
            .entry("sharp")
            .entry("shaw")
            .entry("shell")
            .entry("shia")
            .entry("shiksha")
            .entry("shoes")
            .entry("shop")
            .entry("shopping")
            .entry("shouji")
            .entry("show")
            .entry("showtime")
            .entry("si")
            .entry("silk")
            .entry("sina")
            .entry("singles")
            .entry("site")
            .entry("sj")
            .entry("sk")
            .entry("ski")
            .entry("skin")
            .entry("sky")
            .entry("skype")
            .entry("sl")
            .entry("sling")
            .entry("sm")
            .entry("smart")
            .entry("smile")
            .entry("sn")
            .entry("sncf")
            .entry("so")
            .entry("soccer")
            .entry("social")
            .entry("softbank")
            .entry("software")
            .entry("sohu")
            .entry("solar")
            .entry("solutions")
            .entry("song")
            .entry("sony")
            .entry("soy")
            .entry("spa")
            .entry("space")
            .entry("sport")
            .entry("spot")
            .entry("sr")
            .entry("srl")
            .entry("ss")
            .entry("st")
            .entry("stada")
            .entry("staples")
            .entry("star")
            .entry("statebank")
            .entry("statefarm")
            .entry("stc")
            .entry("stcgroup")
            .entry("stockholm")
            .entry("storage")
            .entry("store")
            .entry("stream")
            .entry("studio")
            .entry("study")
            .entry("style")
            .entry("su")
            .entry("sucks")
            .entry("supplies")
            .entry("supply")
            .entry("support")
            .entry("surf")
            .entry("surgery")
            .entry("suzuki")
            .entry("sv")
            .entry("swatch")
            .entry("swiss")
            .entry("sx")
            .entry("sy")
            .entry("sydney")
            .entry("systems")
            .entry("sz")
            .entry("tab")
            .entry("taipei")
            .entry("talk")
            .entry("taobao")
            .entry("target")
            .entry("tatamotors")
            .entry("tatar")
            .entry("tattoo")
            .entry("tax")
            .entry("taxi")
            .entry("tc")
            .entry("tci")
            .entry("td")
            .entry("tdk")
            .entry("team")
            .entry("tech")
            .entry("technology")
            .entry("tel")
            .entry("temasek")
            .entry("tennis")
            .entry("teva")
            .entry("tf")
            .entry("tg")
            .entry("th")
            .entry("thd")
            .entry("theater")
            .entry("theatre")
            .entry("tiaa")
            .entry("tickets")
            .entry("tienda")
            .entry("tiffany")
            .entry("tips")
            .entry("tires")
            .entry("tirol")
            .entry("tj")
            .entry("tjmaxx")
            .entry("tjx")
            .entry("tk")
            .entry("tkmaxx")
            .entry("tl")
            .entry("tm")
            .entry("tmall")
            .entry("tn")
            .entry("to")
            .entry("today")
            .entry("tokyo")
            .entry("tools")
            .entry("top")
            .entry("toray")
            .entry("toshiba")
            .entry("total")
            .entry("tours")
            .entry("town")
            .entry("toyota")
            .entry("toys")
            .entry("tr")
            .entry("trade")
            .entry("trading")
            .entry("training")
            .entry("travel")
            .entry("travelchannel")
            .entry("travelers")
            .entry("travelersinsurance")
            .entry("trust")
            .entry("trv")
            .entry("tt")
            .entry("tube")
            .entry("tui")
            .entry("tunes")
            .entry("tushu")
            .entry("tv")
            .entry("tvs")
            .entry("tw")
            .entry("tz")
            .entry("ua")
            .entry("ubank")
            .entry("ubs")
            .entry("ug")
            .entry("uk")
            .entry("unicom")
            .entry("university")
            .entry("uno")
            .entry("uol")
            .entry("ups")
            .entry("us")
            .entry("uy")
            .entry("uz")
            .entry("va")
            .entry("vacations")
            .entry("vana")
            .entry("vanguard")
            .entry("vc")
            .entry("ve")
            .entry("vegas")
            .entry("ventures")
            .entry("verisign")
            .entry("versicherung")
            .entry("vet")
            .entry("vg")
            .entry("vi")
            .entry("viajes")
            .entry("video")
            .entry("vig")
            .entry("viking")
            .entry("villas")
            .entry("vin")
            .entry("vip")
            .entry("virgin")
            .entry("visa")
            .entry("vision")
            .entry("viva")
            .entry("vivo")
            .entry("vlaanderen")
            .entry("vn")
            .entry("vodka")
            .entry("volkswagen")
            .entry("volvo")
            .entry("vote")
            .entry("voting")
            .entry("voto")
            .entry("voyage")
            .entry("vu")
            .entry("vuelos")
            .entry("wales")
            .entry("walmart")
            .entry("walter")
            .entry("wang")
            .entry("wanggou")
            .entry("watch")
            .entry("watches")
            .entry("weather")
            .entry("weatherchannel")
            .entry("webcam")
            .entry("weber")
            .entry("website")
            .entry("wed")
            .entry("wedding")
            .entry("weibo")
            .entry("weir")
            .entry("wf")
            .entry("whoswho")
            .entry("wien")
            .entry("wiki")
            .entry("williamhill")
            .entry("win")
            .entry("windows")
            .entry("wine")
            .entry("winners")
            .entry("wme")
            .entry("wolterskluwer")
            .entry("woodside")
            .entry("work")
            .entry("works")
            .entry("world")
            .entry("wow")
            .entry("ws")
            .entry("wtc")
            .entry("wtf")
            .entry("xbox")
            .entry("xerox")
            .entry("xfinity")
            .entry("xihuan")
            .entry("xin")
            .entry("xn--11b4c3d")
            .entry("xn--1ck2e1b")
            .entry("xn--1qqw23a")
            .entry("xn--2scrj9c")
            .entry("xn--30rr7y")
            .entry("xn--3bst00m")
            .entry("xn--3ds443g")
            .entry("xn--3e0b707e")
            .entry("xn--3hcrj9c")
            .entry("xn--3pxu8k")
            .entry("xn--42c2d9a")
            .entry("xn--45br5cyl")
            .entry("xn--45brj9c")
            .entry("xn--45q11c")
            .entry("xn--4dbrk0ce")
            .entry("xn--4gbrim")
            .entry("xn--54b7fta0cc")
            .entry("xn--55qw42g")
            .entry("xn--55qx5d")
            .entry("xn--5su34j936bgsg")
            .entry("xn--5tzm5g")
            .entry("xn--6frz82g")
            .entry("xn--6qq986b3xl")
            .entry("xn--80adxhks")
            .entry("xn--80ao21a")
            .entry("xn--80aqecdr1a")
            .entry("xn--80asehdb")
            .entry("xn--80aswg")
            .entry("xn--8y0a063a")
            .entry("xn--90a3ac")
            .entry("xn--90ae")
            .entry("xn--90ais")
            .entry("xn--9dbq2a")
            .entry("xn--9et52u")
            .entry("xn--9krt00a")
            .entry("xn--b4w605ferd")
            .entry("xn--bck1b9a5dre4c")
            .entry("xn--c1avg")
            .entry("xn--c2br7g")
            .entry("xn--cck2b3b")
            .entry("xn--cckwcxetd")
            .entry("xn--cg4bki")
            .entry("xn--clchc0ea0b2g2a9gcd")
            .entry("xn--czr694b")
            .entry("xn--czrs0t")
            .entry("xn--czru2d")
            .entry("xn--d1acj3b")
            .entry("xn--d1alf")
            .entry("xn--e1a4c")
            .entry("xn--eckvdtc9d")
            .entry("xn--efvy88h")
            .entry("xn--fct429k")
            .entry("xn--fhbei")
            .entry("xn--fiq228c5hs")
            .entry("xn--fiq64b")
            .entry("xn--fiqs8s")
            .entry("xn--fiqz9s")
            .entry("xn--fjq720a")
            .entry("xn--flw351e")
            .entry("xn--fpcrj9c3d")
            .entry("xn--fzc2c9e2c")
            .entry("xn--fzys8d69uvgm")
            .entry("xn--g2xx48c")
            .entry("xn--gckr3f0f")
            .entry("xn--gecrj9c")
            .entry("xn--gk3at1e")
            .entry("xn--h2breg3eve")
            .entry("xn--h2brj9c")
            .entry("xn--h2brj9c8c")
            .entry("xn--hxt814e")
            .entry("xn--i1b6b1a6a2e")
            .entry("xn--imr513n")
            .entry("xn--io0a7i")
            .entry("xn--j1aef")
            .entry("xn--j1amh")
            .entry("xn--j6w193g")
            .entry("xn--jlq480n2rg")
            .entry("xn--jlq61u9w7b")
            .entry("xn--jvr189m")
            .entry("xn--kcrx77d1x4a")
            .entry("xn--kprw13d")
            .entry("xn--kpry57d")
            .entry("xn--kput3i")
            .entry("xn--l1acc")
            .entry("xn--lgbbat1ad8j")
            .entry("xn--mgb9awbf")
            .entry("xn--mgba3a3ejt")
            .entry("xn--mgba3a4f16a")
            .entry("xn--mgba7c0bbn0a")
            .entry("xn--mgbaakc7dvf")
            .entry("xn--mgbaam7a8h")
            .entry("xn--mgbab2bd")
            .entry("xn--mgbah1a3hjkrd")
            .entry("xn--mgbai9azgqp6j")
            .entry("xn--mgbayh7gpa")
            .entry("xn--mgbbh1a")
            .entry("xn--mgbbh1a71e")
            .entry("xn--mgbc0a9azcg")
            .entry("xn--mgbca7dzdo")
            .entry("xn--mgbcpq6gpa1a")
            .entry("xn--mgberp4a5d4ar")
            .entry("xn--mgbgu82a")
            .entry("xn--mgbi4ecexp")
            .entry("xn--mgbpl2fh")
            .entry("xn--mgbt3dhd")
            .entry("xn--mgbtx2b")
            .entry("xn--mgbx4cd0ab")
            .entry("xn--mix891f")
            .entry("xn--mk1bu44c")
            .entry("xn--mxtq1m")
            .entry("xn--ngbc5azd")
            .entry("xn--ngbe9e0a")
            .entry("xn--ngbrx")
            .entry("xn--node")
            .entry("xn--nqv7f")
            .entry("xn--nqv7fs00ema")
            .entry("xn--nyqy26a")
            .entry("xn--o3cw4h")
            .entry("xn--ogbpf8fl")
            .entry("xn--otu796d")
            .entry("xn--p1acf")
            .entry("xn--p1ai")
            .entry("xn--pgbs0dh")
            .entry("xn--pssy2u")
            .entry("xn--q7ce6a")
            .entry("xn--q9jyb4c")
            .entry("xn--qcka1pmc")
            .entry("xn--qxa6a")
            .entry("xn--qxam")
            .entry("xn--rhqv96g")
            .entry("xn--rovu88b")
            .entry("xn--rvc1e0am3e")
            .entry("xn--s9brj9c")
            .entry("xn--ses554g")
            .entry("xn--t60b56a")
            .entry("xn--tckwe")
            .entry("xn--tiq49xqyj")
            .entry("xn--unup4y")
            .entry("xn--vermgensberater-ctb")
            .entry("xn--vermgensberatung-pwb")
            .entry("xn--vhquv")
            .entry("xn--vuq861b")
            .entry("xn--w4r85el8fhu5dnra")
            .entry("xn--w4rs40l")
            .entry("xn--wgbh1c")
            .entry("xn--wgbl6a")
            .entry("xn--xhq521b")
            .entry("xn--xkc2al3hye2a")
            .entry("xn--xkc2dl3a5ee0h")
            .entry("xn--y9a3aq")
            .entry("xn--yfro4i67o")
            .entry("xn--ygbi2ammx")
            .entry("xn--zfr164b")
            .entry("xxx")
            .entry("xyz")
            .entry("yachts")
            .entry("yahoo")
            .entry("yamaxun")
            .entry("yandex")
            .entry("ye")
            .entry("yodobashi")
            .entry("yoga")
            .entry("yokohama")
            .entry("you")
            .entry("youtube")
            .entry("yt")
            .entry("yun")
            .entry("za")
            .entry("zappos")
            .entry("zara")
            .entry("zero")
            .entry("zip")
            .entry("zm")
            .entry("zone")
            .entry("zuerich")
            .entry("zw")
            .build()
    )
    .unwrap();
}
